==> python-hug_2.3.0.orig.tar.gz: hug-2.3.0/hug/_async.py <==
"""hug/_async.py

Defines all required async glue code

Copyright (C) 2016  Timothy Edmund Crosley

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

"""
import sys

try:
    import asyncio

    if sys.version_info >= (3, 4, 4):
        ensure_future = asyncio.ensure_future  # pragma: no cover
    else:
        ensure_future = asyncio.async  # pragma: no cover

    def asyncio_call(function, *args, **kwargs):
        try:
            loop = asyncio.get_event_loop()
        except RuntimeError: # pragma: no cover
            loop = asyncio.new_event_loop()
            asyncio.set_event_loop(loop)
        if loop.is_running():
            return function(*args, **kwargs)

        function = ensure_future(function(*args, **kwargs), loop=loop)
        loop.run_until_complete(function)
        return function.result()

    coroutine = asyncio.coroutine

except ImportError:  # pragma: no cover
    asyncio = None

    def asyncio_call(*args, **kwargs):
        raise NotImplementedError()

    def ensure_future(*args, **kwargs):
        raise NotImplementedError()

    def coroutine(function):
        return function

==> python-hug_2.4.1.orig.tar.gz: hug-2.4.1/hug/_async.py <==
"""hug/_async.py

Defines all required async glue code

Copyright (C) 2016  Timothy Edmund Crosley

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

"""
import sys

try:
    import asyncio

    if sys.version_info >= (3, 4, 4):
        ensure_future = asyncio.ensure_future  # pragma: no cover
    else:
        ensure_future = getattr('asyncio', 'async')  # pragma: no cover

    def asyncio_call(function, *args, **kwargs):
        try:
            loop = asyncio.get_event_loop()
        except RuntimeError: # pragma: no cover
            loop = asyncio.new_event_loop()
            asyncio.set_event_loop(loop)
        if loop.is_running():
            return function(*args, **kwargs)

        function = ensure_future(function(*args, **kwargs), loop=loop)
        loop.run_until_complete(function)
        return function.result()

    coroutine = asyncio.coroutine

except ImportError:  # pragma: no cover
    asyncio = None

    def asyncio_call(*args, **kwargs):
        raise NotImplementedError()

    def ensure_future(*args, **kwargs):
        raise NotImplementedError()

    def coroutine(function):
        return function
